==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebFilteringStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringStrategyDescription } from "./WebFilteringStrategyDescription";
/**
 * @hidden
 */
var WebFilteringStrategyDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebFilteringStrategyDescriptionMetadata, _super);
    function WebFilteringStrategyDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFilteringStrategyDescriptionMetadata.b = function (a) {
        if (WebFilteringStrategyDescriptionMetadata.a == null) {
            WebFilteringStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFilteringStrategyDescriptionMetadata.c(WebFilteringStrategyDescriptionMetadata.a);
        }
        if (a.j(WebFilteringStrategyDescriptionMetadata.a)) {
            return;
        }
        a.y(WebFilteringStrategyDescriptionMetadata.a);
    };
    WebFilteringStrategyDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FilteringStrategy");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
    };
    WebFilteringStrategyDescriptionMetadata.d = function (a) {
        WebFilteringStrategyDescriptionMetadata.b(a);
        a.aa("WebFilteringStrategy", function () { return new WebFilteringStrategyDescription(); });
        a.z("WebFilteringStrategy", WebFilteringStrategyDescriptionMetadata.a);
    };
    WebFilteringStrategyDescriptionMetadata.$t = markType(WebFilteringStrategyDescriptionMetadata, 'WebFilteringStrategyDescriptionMetadata');
    WebFilteringStrategyDescriptionMetadata.a = null;
    return WebFilteringStrategyDescriptionMetadata;
}(Base));
export { WebFilteringStrategyDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebFilteringStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringStrategyDescription } from "./WebFilteringStrategyDescription";
/**
 * @hidden
 */
var WebFilteringStrategyDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebFilteringStrategyDescriptionMetadata, _super);
    function WebFilteringStrategyDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFilteringStrategyDescriptionMetadata.b = function (a) {
        if (WebFilteringStrategyDescriptionMetadata.a == null) {
            WebFilteringStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFilteringStrategyDescriptionMetadata.c(WebFilteringStrategyDescriptionMetadata.a);
        }
        if (a.k(WebFilteringStrategyDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebFilteringStrategyDescriptionMetadata.a);
    };
    WebFilteringStrategyDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FilteringStrategy");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
    };
    WebFilteringStrategyDescriptionMetadata.d = function (a) {
        WebFilteringStrategyDescriptionMetadata.b(a);
        a.ac("WebFilteringStrategy", function () { return new WebFilteringStrategyDescription(); });
        a.ab("WebFilteringStrategy", WebFilteringStrategyDescriptionMetadata.a);
    };
    WebFilteringStrategyDescriptionMetadata.$t = markType(WebFilteringStrategyDescriptionMetadata, 'WebFilteringStrategyDescriptionMetadata');
    WebFilteringStrategyDescriptionMetadata.a = null;
    return WebFilteringStrategyDescriptionMetadata;
}(Base));
export { WebFilteringStrategyDescriptionMetadata };
